@@ -16,7 +16,7 @@ import caching.base
 # Create your models here.
 
 
-from linghelper import DTW,disambiguate_sense,get_semantic_predictability
+from linghelper import DTW,SemanticPredictabilityAnalyzer
 from praatinterface import PraatLoader
 
 if 'phonostats' in settings.INSTALLED_APPS:
@@ -36,6 +36,7 @@ from .helper import fetch_buckeye_resource,reorganize
 from .managers import BulkManager
 
 
+SEM_PRED = SemanticPredictabilityAnalyzer(ngram=True,use_idf=True)
 
 
 GOOD_WORDS = ['back', 'bad', 'badge', 'bag', 'ball', 'bar', 'bare', 'base', 'bash', 'bass', 'bat', 'bath', 'beach', 'bean', 'bear', 'beat',
@@ -666,7 +667,7 @@ class WordToken(caching.base.CachingMixin,models.Model):
             prev = self.getPreviousContext(window=10)
             foll = self.getFollowingContext(window=10)
             context = [str(x) for x in prev] + [str(x) for x in foll]
-            self.Output['Wordnet_sense'] = disambiguate_sense(str(self),cat,context,to_string=True)
+            self.Output['Wordnet_sense'] = SEM_PRED.disambiguate_sense(str(self),cat,context,to_string=True)
             self.save()
         return self.Output['Wordnet_sense']
 
@@ -682,7 +683,7 @@ class WordToken(caching.base.CachingMixin,models.Model):
         sense = self.get_sense(disambiguate=disambiguate)
         if sense is None:
             return None
-        sp = get_semantic_predictability(sense,prev_context,style=style)
+        sp = SEM_PRED.get_semantic_predictability(sense,prev_context,style=style)
         if style == 'A' and window == 'A':
             self.PrevSemPred = sp
             self.save()
@@ -700,7 +701,7 @@ class WordToken(caching.base.CachingMixin,models.Model):
         sense = self.get_sense(disambiguate=disambiguate)
         if sense is None:
             return None
-        sp = get_semantic_predictability(sense,foll_context,style=style)
+        sp = SEM_PRED.get_semantic_predictability(sense,foll_context,style=style)
         if style == 'A' and window == 'A':
             self.FollSemPred = sp
             self.save()
